---
# Release Notes

## 2.4.0
* (Enhancement) Add `help` command for comprehensive command help.
* (Bug Fix) Disable option validity checking when `--help` is specified.
## 2.3.0
* (Enhancement) Allow users to choose account name for S3 access.
## 2.2.4
* (Chore) Update dependency versions.
## 2.2.3
* (Enhancement) Support new certificate download endpoint on Cyral Control Plane.
## 2.2.2
* (Bug Fix) Support `aws s3api` command.
## 2.2.1
* (Bug Fix) Make changes compatible with Python version 3.9.
## 2.2.0
* (Enhancement) Add `sidecar` command.
## 2.1.1
* (Enhancement) Add `--realm` option to support some older control planes.
## 2.0.1
* (Bug Fix) Choose non-proxy mode port for S3 repo.
## 2.0.0
* (Enhancement) Add support for Cyral Control Plane v4.x.
---
